@@ -1,16 +1,16 @@
 import json
 from io import BytesIO
 
-from mcap.mcap0.records import ChunkIndex
-from mcap.mcap0.stream_reader import StreamReader
-from mcap.mcap0.writer import Writer
+from mcap.records import ChunkIndex
+from mcap.stream_reader import StreamReader
+from mcap.writer import Writer
 
 
 def test_json_schema():
     output = BytesIO()
     writer = Writer(output)
 
-    writer.start(profile="x-custom", library="my-writer-v1")
+    writer.start()
 
     schema_id = writer.register_schema(
         name="foxglove.FrameTransform",
